@@ -33,9 +33,10 @@
 #  define ANALITZAGUI_DEPRECATED_NO_EXPORT ANALITZAGUI_NO_EXPORT ANALITZAGUI_DEPRECATED
 #endif
 
-#define DEFINE_NO_DEPRECATED 0
-#if DEFINE_NO_DEPRECATED
-# define ANALITZAGUI_NO_DEPRECATED
+#if 0 /* DEFINE_NO_DEPRECATED */
+#  ifndef ANALITZAGUI_NO_DEPRECATED
+#    define ANALITZAGUI_NO_DEPRECATED
+#  endif
 #endif
 
 #endif
