@@ -33,9 +33,10 @@
 #  define ANALITZAWIDGETS_DEPRECATED_NO_EXPORT ANALITZAWIDGETS_NO_EXPORT ANALITZAWIDGETS_DEPRECATED
 #endif
 
-#define DEFINE_NO_DEPRECATED 0
-#if DEFINE_NO_DEPRECATED
-# define ANALITZAWIDGETS_NO_DEPRECATED
+#if 0 /* DEFINE_NO_DEPRECATED */
+#  ifndef ANALITZAWIDGETS_NO_DEPRECATED
+#    define ANALITZAWIDGETS_NO_DEPRECATED
+#  endif
 #endif
 
 #endif
